==> haskell-network-2.6.3.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network
version: 2.6.3.4
id: network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT
key: network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT
license: BSD3
maintainer: Kazu Yamamoto, Evan Borden
homepage: https://github.com/haskell/network
synopsis: Low-level networking interface
description:
    This package provides a low-level networking interface.
    .
    In network-2.6 the @Network.URI@ module was split off into its own
    package, network-uri-2.6. If you'\''re using the @Network.URI@ module
    you can automatically get it from the right package by adding this
    to your .cabal file:
    .
    > library
    >   build-depends: network-uri-flag
category: Network
exposed: True
indefinite: False
exposed-modules:
    Network Network.BSD Network.Socket Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal
hidden-modules: Network.Socket.ByteString.Internal
                Network.Socket.Types Network.Socket.ByteString.IOVec
                Network.Socket.ByteString.Lazy.Posix
                Network.Socket.ByteString.MsgHdr
abi: 3bb40bf00d3257de945a134963a298b0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/network-2.6.3.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/network-2.6.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/network-2.6.3.4
hs-libraries: HSnetwork-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT
include-dirs: /usr/lib/ghc-8.2.2/site-local/network-2.6.3.4/include
includes:
    HsNet.h
depends:
    base-4.10.1.0 bytestring-0.10.8.2 unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces: /usr/share/doc/haskell-network/html/network.haddock
haddock-html: /usr/share/doc/haskell-network/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-2.6.3.5-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network
version: 2.6.3.5
id: network-2.6.3.5-BVJHDRdh5LJ4pgucNKJkuJ
key: network-2.6.3.5-BVJHDRdh5LJ4pgucNKJkuJ
license: BSD3
maintainer: Kazu Yamamoto, Evan Borden
homepage: https://github.com/haskell/network
synopsis: Low-level networking interface
description:
    This package provides a low-level networking interface.
    .
    In network-2.6 the @Network.URI@ module was split off into its own
    package, network-uri-2.6. If you'\''re using the @Network.URI@ module
    you can automatically get it from the right package by adding this
    to your .cabal file:
    .
    > library
    >   build-depends: network-uri-flag
category: Network
exposed: True
indefinite: False
exposed-modules:
    Network Network.BSD Network.Socket Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal
hidden-modules: Network.Socket.ByteString.Internal
                Network.Socket.Types Network.Socket.ByteString.IOVec
                Network.Socket.ByteString.Lazy.Posix
                Network.Socket.ByteString.MsgHdr
abi: 82fe21e10301e2e4d8701392ba21a740
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/network-2.6.3.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/network-2.6.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/network-2.6.3.5
hs-libraries: HSnetwork-2.6.3.5-BVJHDRdh5LJ4pgucNKJkuJ
include-dirs: /usr/lib/ghc-8.2.2/site-local/network-2.6.3.5/include
includes:
    HsNet.h
depends:
    base-4.10.1.0 bytestring-0.10.8.2 unix-2.7.2.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces: /usr/share/doc/haskell-network/html/network.haddock
haddock-html: /usr/share/doc/haskell-network/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
